@@ -38,12 +38,12 @@ OC.L10N.register(
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
     "Reminders" : "Recordatorios",
-    "Activity" : "Actividá",
     "Close" : "Zarrar",
     "Anniversary" : "Aniversariu",
     "Week {number} of {year}" : "Selmana {number} del {year}",
     "Daily" : "Caldía",
     "Weekly" : "Selmanalmente",
+    "today" : "güei",
     "When shared show full event" : "Amosar l'eventu completu al compartir",
     "When shared show only busy" : "Amosar namás ocupáu al compartir",
     "When shared hide this event" : "Anubrir l'eventu al compartir",
@@ -52,7 +52,6 @@ OC.L10N.register(
     "Status" : "Estáu",
     "Confirmed" : "Confirmáu",
     "Tentative" : "Tentativa",
-    "Cancelled" : "Encaboxáu",
     "Categories" : "Estayes",
     "Presentation" : "Presentación",
     "Office" : "Oficina",
