@@ -25,10 +25,10 @@ OC.L10N.register(
     "Personal" : "Şəxsi",
     "Details" : "Detallar",
     "Attendees" : "İştirakçılar",
-    "Activity" : "Fəallıq",
     "Close" : "Bağla",
     "Daily" : "Günlük",
     "Weekly" : "Həftəlik",
+    "today" : "Bu gün",
     "Location" : "Yerləşdiyiniz ünvan",
     "Description" : "Açıqlanma",
     "Mail" : "Məktub",
