@@ -36,10 +36,10 @@ OC.L10N.register(
     "Details" : "Manylion",
     "Attendees" : "Mynychwyr",
     "Reminders" : "Nodau atgoffa",
-    "Activity" : "Gweithred",
     "Close" : "Cau",
     "Anniversary" : "Dathliad",
     "Week {number} of {year}" : "Wythnos {number} o {year}",
+    "today" : "heddiw",
     "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
     "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
     "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
@@ -47,7 +47,6 @@ OC.L10N.register(
     "Description" : "Disgrifiad",
     "Confirmed" : "Cadarnhawyd",
     "Tentative" : "I'w gadarnhau",
-    "Cancelled" : "Diddymwyd",
     "Mail" : "E-bost",
     "Play" : "Chwarae",
     "Global" : "Eang"
