@@ -10,6 +10,7 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Jakinarazi nahi dizugu %s erabiltzaileak »%s« egutegia argitaratu duela",
     "Open »%s«" : " Ireki »%s«",
     "Cheers!" : "Topa!",
+    "Upcoming events" : "Hurrengo gertaerak",
     "Calendar" : "Egutegia",
     "A Calendar app for Nextcloud" : "Nextclouderako egutegi app-a",
     "Previous day" : "Aurreko eguna",
@@ -162,7 +163,7 @@ OC.L10N.register(
     "No match found" : "Ez da emaitzarik aurkitu",
     "No attendees yet" : "Partaiderik ez oraindik",
     "(organizer)" : "(antolatzailea)",
-    "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "Gonbidapenak bidali eta erantzunak kudeatzeko,  [linkopen]gehitu zure helbide elektronikoa ezarpen pertsonaletan[linkclose].",
+    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Gonbidapenak bidali eta erantzunak kudeatzeko, [linkopen] gehitu zure posta helbidea ezarpen pertsonaletan[linkclose].",
     "Remove color" : "Kendu kolorea",
     "Event title" : "Gertaeraren izenburua",
     "All day" : "Egun osoa",
@@ -219,9 +220,13 @@ OC.L10N.register(
     "Personal" : "Pertsonala",
     "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Ordu-eremu detekzio automatikoak zehaztu du zure ordu-eremua UTC dela. Hau seguru aski zure nabigatzailearen segurtasun neurrien ondorio da. Zehaztu ezazu zure ordu-eremua eskuz egutegiaren ezarpenetan.",
     "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Ezarrita daukazun ordu-eremua ({timezoneId}) ez da aurkitu. UTC-ra itzultzen. Mesedez, aldatu zure ordu-eremua ezarpenetan eta eman arazoaren berri.",
+    "No more events today" : "Ez dago gertaera gehiagorik gaurkoz.",
+    "No upcoming events" : "Ez dago gertaerarik datozen egunetan.",
+    "Create a new event" : "Sortu gertaera berri bat",
     "[Today]" : "[Gaur]",
     "[Tomorrow]" : "[Bihar]",
     "[Yesterday]" : "[Atzo]",
+    "Event does not exist" : "Ez dago gertaera hori",
     "Delete this occurrence" : "Ezabatu gertaera hau",
     "Delete this and all future" : "Ezabatu hau eta etorkizunekoak",
     "Details" : "Xehetasunak",
@@ -231,7 +236,7 @@ OC.L10N.register(
     "Show more details" : "Erakutsi xehetasun gehiago",
     "Subscribe to {name}" : "Harpidetu {name}",
     "Download {name}" : "Deskargatu {name}",
-    "Anniversary" : "Urteurrena",
+    "Anniversary" : "Urtebetetzea / urteurrena",
     "Appointment" : "Hitzordua",
     "Business" : "Lana",
     "Education" : "Hezkuntza",
@@ -288,6 +293,8 @@ OC.L10N.register(
     "%n more" : "%n gehiago",
     "No events to display" : "Ez dago bistaratzeko gertaerarik",
     "_+%n more_::_+%n more_" : ["+ %n","+ %n"],
+    "No events" : "Ez dago gertaerarik",
+    "Create a new event or change the visible time-range" : "Sortu gertaera berria edo aldatu ikusgai dagoen epea",
     "When shared show" : "Partekatzean erakutsi",
     "When shared show full event" : "Partekatzean erakutsi gertaera osoa",
     "When shared show only busy" : "Partekatzean okupatua bezala erakutsi soilik",
