@@ -1,6 +1,7 @@
 OC.L10N.register(
     "calendar",
     {
+    "User-Session unexpectedly expired" : "Корисничката-сесија е застарена",
     "Provided email-address is not valid" : "Адресата на е-пошта не е правилно внесена",
     "%s has published the calendar »%s«" : "%s Објави календар »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Неочекувана грешка при испраќање на е-пошта. Контактирајте го администраторот.",
@@ -9,6 +10,7 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Сакаме да те информираме дека %s објави календар »%s«.",
     "Open »%s«" : "Отвори »%s«",
     "Cheers!" : "Поздрав!",
+    "Upcoming events" : "Престојни настани",
     "Calendar" : "Календар",
     "A Calendar app for Nextcloud" : "Календар апликација за Nextcloud",
     "Previous day" : "Предходен ден",
@@ -22,6 +24,7 @@ OC.L10N.register(
     "Day" : "Ден",
     "Week" : "Недела",
     "Month" : "Месец",
+    "List" : "Лист",
     "Untitled calendar" : "Неименуван календар",
     "Edit name" : "Уреди име",
     "Saving name …" : "Зачувување име …",
@@ -60,34 +63,56 @@ OC.L10N.register(
     "An error occurred, unable to send email." : "Настана грешка, неможе да се испрати е-пошта.",
     "Embed code copied to clipboard." : "Кодот за вградување е копиран во клипборд.",
     "Embed code could not be copied to clipboard." : "Кодот за вградување неможе да се копира во клипборд.",
+    "Unpublishing calendar failed" : "Неуспешно од-објавување на календар",
     "Share with users or groups" : "Сподели со корисници или групи",
     "No users or groups" : "Нема корисници или групи",
     "can edit" : "може да се измени",
+    "Unshare with {displayName}" : "Не споделувај со {displayName}",
+    "An error occurred, unable to change the unshare the calendar." : "Настана грешка, неможе да се промени споделувањето на календарот.",
     "An error occurred, unable to change the permission of the share." : "Настана грешка, неможе да се променат дозволите за споделување.",
     "+ New calendar" : "+ Нов календар",
     "New calendar" : "Нов календар",
     "Creating calendar …" : "Креирање календар …",
     "New calendar with task list" : "Нов календар со листа на задачи",
+    "New subscription from link (read-only)" : "Нова претплата од линк (само за читање)",
+    "Creating subscription …" : "Креирање претплата  …",
     "An error occurred, unable to create the calendar." : "Настана грешка, неможе да се креира календар.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Внесете валиден линк (започнувајчи со http://, https://, webcal://, или webcals://)",
+    "Could not update calendar order." : "Неможе да се ажурира редоследот на календарите.",
     "Import calendars" : "Увези календари",
     "Please select a calendar to import into …" : "Изберете календар за да направите увоз во него …",
     "Filename" : "Име на датотека",
     "Calendar to import into" : "Календар за да направите увоз во него",
     "Cancel" : "Откажи",
     "_Import calendar_::_Import calendars_" : ["Увези календар","Увези календари"],
+    "{filename} is an unsupported file-type" : "Видот на датотеката {filename} не е поддржана",
+    "{filename} could not be parsed" : "Датотеката {filename} не може да се анализира",
+    "No valid files found, aborting import" : "Не е пронајдена валидна датотека, увозот е откажан",
     "Import partially failed. Imported {accepted} out of {total}." : "Увозот е делумно неуспешен. Увезени {accepted} од вкупно {total}.",
     "_Successfully imported %n event_::_Successfully imported %n events._" : ["Успешно увезен %n настан","Успешно увезени %n настани."],
     "Automatic" : "Автоматски",
     "Automatic ({detected})" : "Автоматски ({detected})",
+    "New setting was not saved successfully." : "Неуспешно зачувување на промените.",
+    "Shortcut overview" : "Преглед на кратенки преку тастатура",
     "or" : "или",
     "Navigation" : "Навигација",
+    "Previous period" : "Предходен период",
+    "Next period" : "Следен период",
+    "Views" : "Прегледи",
+    "Day view" : "Дневен преглед",
+    "Week view" : "Неделен преглед",
+    "Month view" : "Месечен преглед",
     "Actions" : "Акции",
+    "Create event" : "Креирај настан",
     "Show shortcuts" : "Прикажи кратенки",
     "Enable birthday calendar" : "Овозможи календар со родендени",
+    "Show tasks in calendar" : "Прикажи ги задачите во календарнот",
     "Enable simplified editor" : "Овозможи поедноставен уредувач",
+    "Limit visible events per view" : "Ограни ги видливите настани по преглед",
     "Show weekends" : "Прикажи викенди",
     "Show week numbers" : "Прикажи броеви на неделите",
+    "Copy primary CalDAV address" : "Копирај примарна CalDAV адреса",
+    "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
     "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура",
     "Settings & import" : "Параметри & импорт",
     "CalDAV link copied to clipboard." : "CalDAV линкот е копиран.",
@@ -97,11 +122,12 @@ OC.L10N.register(
     "Email" : "Е-пошта",
     "Audio notification" : "Аудио известување",
     "Other notification" : "Друго и звестување",
+    "Relative to event" : "Релативно на настан",
     "On date" : "На датум",
     "Edit time" : "Удери време",
     "Save time" : "Зачувај време",
     "Remove reminder" : "Отстрани потсетник",
-    "on" : "на",
+    "on" : "во",
     "at" : "во",
     "+ Add reminder" : "+ Додади потсетник",
     "_second_::_seconds_" : ["секунда","секунди"],
@@ -110,6 +136,7 @@ OC.L10N.register(
     "_day_::_days_" : ["ден","дена"],
     "_week_::_weeks_" : ["недела","недели"],
     "No reminders yet" : "Сеуште нема потсетници",
+    "Availability of attendees, resources and rooms" : "Достапност на присутните, ресурси и соби",
     "Busy (tentative)" : "Зафатен (привремено)",
     "Busy" : "Зафатен",
     "Out of office" : "Надвор од канцеларија",
@@ -118,21 +145,28 @@ OC.L10N.register(
     "{name} accepted {organizerName}'s invitation." : "{name} ја прифати поканата од {organizerName}.",
     "{name} declined your invitation." : "{name} ја одби вашата покана.",
     "{name} declined {organizerName}'s invitation." : "{name} ја одби поканата од {organizerName}.",
+    "{name} has delegated their invitation." : "{name} одговори на неговата покана.",
+    "{name} marked their participation as tentative." : "{name} го означи неговото учество како пробно.",
     "{name} did not respond to your invitation yet." : "{name} сеуште нема одговорено на поканата.",
     "{name} did not respond to {organizerName}'s invitation yet." : "{name} сеуште нема одговорено на поканата од {organizerName}.",
+    "Create Talk room for this event" : "Креирај соба за разговор за овој настан",
     "Show busy times" : "Прикажи ги зафатените термини",
+    "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
+    "Error creating Talk room" : "Грешка при креирање на соба за разговор",
     "Send e-mail" : "Испрати пошта",
-    "Chairperson" : "Претседател",
+    "Chairperson" : "Претседавач",
     "Required participant" : "Задолжителен учесник",
+    "Optional participant" : "Незадолжителен учесник",
+    "Non-participant" : "Не-учесник",
     "Remove attendee" : "Откажи присутност",
     "Search for e-mails, users, contacts, resources or rooms" : "Пребарувај за е-пошти, корисници, контакти, ресурси или соби",
     "No match found" : "Нема совпаѓања",
     "No attendees yet" : "Сè уште нема присутни",
     "(organizer)" : "(organizer)",
-    "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
+    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
     "Remove color" : "Отстрани боја",
     "Event title" : "Наслов на настанот",
-    "All day" : "Сите денови",
+    "All day" : "Цели денови",
     "from {startDate}" : "од {startDate}",
     "from {startDate} at {startTime}" : "од {startDate} во {startTime}",
     "to {endDate}" : "до {endDate}",
@@ -147,7 +181,7 @@ OC.L10N.register(
     "third" : "трети",
     "fourth" : "четврти",
     "fifth" : "петти",
-    "second to last" : "втор до последен",
+    "second to last" : "претпоследен",
     "last" : "последен",
     "Repeat" : "Повтори",
     "Repeat every" : "Повтори секој",
@@ -157,10 +191,13 @@ OC.L10N.register(
     "_year_::_years_" : ["година","години"],
     "Monday" : "Понеделник",
     "weekday" : "недели",
+    "weekend day" : "ден од викенд",
     "Summary" : "Резиме",
     "More" : "Повеќе",
     "Save" : "Зачувај",
     "Update" : "Ажурирај",
+    "Update this occurrence" : "Ажурирајте ја оваа можност",
+    "Update this and all future" : "Ажурирајте го овој и сите во иднина",
     "Public calendar does not exist" : "Јавниот календар не постои",
     "Maybe the share was deleted or has expired?" : "Можеби споделувањето е избришано ики рокот му е поминат?",
     "Please select a timezone:" : "Изберете временска зона:",
@@ -177,17 +214,23 @@ OC.L10N.register(
     "Please enter a valid date and time" : "Внесете валиден датум и време",
     "Type to search timezone" : "Пребарај временски зони",
     "Personal" : "Лично",
+    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Автоматското откривање на временската зона утврди дека вашата временска зона е UTC.\nОва е најверојатно резултат на безбедносните мерки на вашиот веб прелистувач\nПоставете ја вашата временска зона во подесувањата за календарот.",
+    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Вашата временска зона ({timezoneId}) не е пронајдена. Поставена е  (Координирано универзално време) UTC.\nПоставете ја вашата временска зона во подесувањата за календарот или пријавете го овој проблем.",
+    "No more events today" : "Нема настани за денес",
+    "No upcoming events" : "Нема престојни настани",
+    "Create a new event" : "Креирајте нов настан",
     "[Today]" : "[Денес]",
     "[Tomorrow]" : "[Утре]",
     "[Yesterday]" : "[Вчера]",
     "[Last] dddd" : "[Последна] dddd",
+    "Event does not exist" : "Настанот не постои",
     "Delete this occurrence" : "Избришете ја оваа можност",
-    "Delete this and all future" : "Избришете го овој и сете во иднина",
+    "Delete this and all future" : "Избришете го овој и сите во иднина",
     "Details" : "Детали",
     "Attendees" : "Присутни",
     "Reminders" : "Потсетници",
     "Close" : "Затвори",
-    "Show more details" : "Прикажи повече детали",
+    "Show more details" : "Прикажи повеќе детали",
     "Subscribe to {name}" : "Претплатете се на {name}",
     "Download {name}" : "Преземи {name}",
     "Anniversary" : "Годишнина",
@@ -200,13 +243,16 @@ OC.L10N.register(
     "Non-working hours" : "Неработни часови",
     "Not in office" : "Не во канцеларија",
     "Phone call" : "Телефонски повик",
-    "Sick day" : "Болен ден",
+    "Sick day" : "Боледување",
     "Special occasion" : "Посебна пригода",
     "Travel" : "Патување",
     "Vacation" : "Одмор",
+    "Midnight on the day the event starts" : "На полноќ на денот кога започнува настанот",
     "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["Еден ден пред настанот во {formattedHourMinute}","%n дена пред настанот во {formattedHourMinute}"],
     "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["Една недела пред настанот во {formattedHourMinute}","%n недели пред настанот во {formattedHourMinute}"],
     "on the day of the event at {formattedHourMinute}" : "На денот на настанот во {formattedHourMinute}",
+    "at the event's start" : "на почетокот на настанот",
+    "at the event's end" : "на kraj на настанот",
     "{time} before the event starts" : "{time} пред да започне настанот",
     "{time} before the event ends" : "{time} пред да заврши настанот",
     "{time} after the event starts" : "{time} откако ќе започне настанот",
@@ -224,11 +270,15 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["Секој месец","Секој %n месеци"],
     "_Every %n year_::_Every %n years_" : ["Секоја година","Секој %n години"],
     "_on {weekday}_::_on {weekdays}_" : ["во {weekday}","во {weekdays}"],
+    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["на ден {dayOfMonthList}","на денови {dayOfMonthList}"],
+    "on the {ordinalNumber} {byDaySet}" : "на {ordinalNumber} {byDaySet}",
     "in {monthNames}" : "во {monthNames}",
+    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "во {monthNames} на {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "до {untilDate}",
     "_%n time_::_%n times_" : ["уште еднаш","%n пати"],
     "Untitled event" : "Неименуван настан",
     "Untitled task" : "Неименувана задача",
+    "Please ask your administrator to enable the Tasks App." : "Замолете го сервер администраторот да ја овозможи апликацијата задачи.",
     "prev" : "предходна",
     "next" : "следна",
     "prev year" : "предходна година",
@@ -236,11 +286,18 @@ OC.L10N.register(
     "today" : "денес",
     "list" : "лист",
     "W" : "Н",
-    "all-day" : "Сите денови",
+    "all-day" : "Цели денови",
     "%n more" : "%n други",
+    "No events to display" : "Нема настани за приказ",
     "_+%n more_::_+%n more_" : ["+%n друг","+%n други"],
+    "No events" : "Нема настани",
+    "Create a new event or change the visible time-range" : "Креирајте нов настан или променете го видливиот временски опсег",
+    "It might have been deleted, or there was a typo in a link" : "Можеби е избришан или има грешка во врската",
+    "It might have been deleted, or there was a typo in the link" : "Можеби е избришан или има грешка во врската",
+    "When shared show" : "Приказ кога е споделен",
     "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
-    "When shared show only busy" : "Кога е споделено покажи зафатен",
+    "When shared show only busy" : "Кога е споделен, прикажи зафатено",
+    "When shared hide this event" : "Кога е споделен, сокриј го настанот",
     "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар.",
     "Location" : "Локација",
     "Add a location" : "Додади локација",
@@ -248,9 +305,10 @@ OC.L10N.register(
     "Add a description" : "Додади опис",
     "Status" : "Статус",
     "Confirmed" : "Потврдено",
-    "Tentative" : "Прелиминарен",
+    "Tentative" : "Пробно",
+    "Canceled" : "Откажано",
     "Confirmation about the overall status of the event." : "Потврда за целокупниот статус на настанот.",
-    "Show as" : "Крикажи како",
+    "Show as" : "Прикажи како",
     "Take this event into account when calculating free-busy information." : "Го има во предвид овој настан при пресметување на информации за слободен-зафатен.",
     "Free" : "Слободен",
     "Categories" : "Категории",
@@ -274,6 +332,8 @@ OC.L10N.register(
     "Baseball" : "Бејзбол",
     "Meet" : "Запознавање",
     "Planning" : "Планирање",
+    "Retrospective" : "Ретроспектива",
+    "Review" : "Преглед",
     "Office" : "Канцеларија",
     "Party" : "Забава",
     "Celebration" : "Прослава",
@@ -308,6 +368,7 @@ OC.L10N.register(
     "Exercise" : "Вежба",
     "Work out" : "Работа",
     "Working out" : "Работење",
+    "Gym" : "Теретана",
     "Barber" : "Бербер",
     "Haircut" : "Пострижување",
     "Exam" : "Испит",
@@ -318,6 +379,11 @@ OC.L10N.register(
     "Running" : "Трчање",
     "Go for a run" : "Одење на трчање",
     "Marathon" : "Маратон",
+    "Video-conference" : "Видео-конференција",
+    "Conference-call" : "Конференција-повик",
+    "Video-call" : "Видео-повик",
+    "Video-chat" : "Видео-разговор",
+    "Video-meeting" : "Видео-состанок",
     "Call" : "Повик",
     "Calling" : "Повикувајќи",
     "Christmas" : "Божиќ",
