@@ -192,20 +192,22 @@ OC.L10N.register(
     "Update this occurrence" : "Oppdater denne hendelsen",
     "Update this and all future" : "Oppdater denne og fremtidige hendelser",
     "Public calendar does not exist" : "Offentlig kalender finnes ikke",
+    "Maybe the share was deleted or has expired?" : "Er deling slettet eller utløpt?",
     "Please select a timezone:" : "Velg en tidssone:",
     "Pick a time" : "Velg et tidspunkt",
     "Pick a date" : "Velg en dato",
     "from {formattedDate}" : "fra {formattedDate}",
     "to {formattedDate}" : "til {formattedDate}",
     "on {formattedDate}" : "på {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} på {formattedDate}",
-    "to {formattedDate} at {formattedTime}" : "til {formattedDate} på {formattedDate}",
-    "on {formattedDate} at {formattedTime}" : "på {formattedDate} på {formattedDate}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} på {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} på {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "til {formattedDate} på {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "på {formattedDate} på {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} på {formattedTime}",
     "Please enter a valid date" : "Vennligst tast inn en gyldig dato",
     "Please enter a valid date and time" : "Vennligst tast inn en gyldig dato og tidspunkt",
     "Type to search timezone" : "Skriv for å finne tidssone",
     "Personal" : "Personlig",
+    "No more events today" : "Ingen flere hendelser i dag",
     "Delete this occurrence" : "Slett denne hendelsen",
     "Delete this and all future" : "Slett denne og fremtidige hendelser",
     "Details" : "Detaljer",
@@ -258,6 +260,7 @@ OC.L10N.register(
     "Search or add categories" : "Søk eller legg til kategorier",
     "Add this as a new category" : "Legg til som ny kategori",
     "Custom color" : "Tilpasset farge",
+    "Special color of this event. Overrides the calendar-color." : "Spesial farge for denne hendelsen. Overstyrer kalenderfargen.",
     "Imported {filename}" : "Importerte {filename}",
     "Meditation" : "Meditasjon",
     "Relaxing" : "Avslapping",
