@@ -33,7 +33,7 @@ OC.L10N.register(
     "Copy private link" : "Kopiera privat länk",
     "Download" : "Hämta",
     "Unshare from me" : "Sluta dela från mig",
-    "Delete" : "Radera",
+    "Delete" : "Ta bort",
     "An error occurred, unable to change visibility of the calendar." : "Ett fel inträffade, kunde inte ändra synlighet på kalendern.",
     "An error occurred, unable to delete the calendar." : "Ett fel inträffade, kunde inte radera kalendern.",
     "Calendar link copied to clipboard." : "Kalenderlänk kopierad till urklipp.",
@@ -57,7 +57,7 @@ OC.L10N.register(
     "Copying code …" : "Kopierar kod …",
     "Copied code" : "Kopierad kod",
     "Could not copy code" : "Kunde inte kopiera kod",
-    "Delete share link" : "Radera delad länk",
+    "Delete share link" : "Ta bort delad länk",
     "Deleting share link …" : "Raderar delad länk …",
     "An error occurred, unable to publish calendar." : "Ett fel inträffade, kunde inte publicera kalendern.",
     "An error occurred, unable to send email." : "Fel uppstod. Mejlet kunde inte skickas.",
@@ -113,7 +113,7 @@ OC.L10N.register(
     "Show week numbers" : "Visa veckonummer",
     "Copy primary CalDAV address" : "Kopiera primär CalDAV-adress",
     "Copy iOS/macOS CalDAV address" : "Kopiera iOS/macOS CalDAV-adress",
-    "Show keyboard shortcuts" : "Visa kortkommandon",
+    "Show keyboard shortcuts" : "Visa tangentbordsgenvägar",
     "Settings & import" : "Inställningar & import",
     "CalDAV link copied to clipboard." : "CalDAV-länk kopierad till urklipp.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-länk kunde inte kopieras till urklipp.",
@@ -126,7 +126,7 @@ OC.L10N.register(
     "On date" : "På datum",
     "Edit time" : "Ändra tid",
     "Save time" : "Lagra tid",
-    "Remove reminder" : "Radera påminnelse",
+    "Remove reminder" : "Ta bort påminnelse",
     "on" : "på",
     "at" : "kl",
     "+ Add reminder" : "+Lägg till påminnelse",
@@ -163,7 +163,6 @@ OC.L10N.register(
     "No match found" : "Ingen träff",
     "No attendees yet" : "Inga deltagare ännu",
     "(organizer)" : "(arrangör)",
-    "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "För att skicka ut inbjudningar och hantera svar,  [linkopen]lägg till din e-postadress i personliga inställningar[linkclose].",
     "Remove color" : "Ta bort färg",
     "Event title" : "Händelsens titel",
     "All day" : "Heldag",
@@ -227,8 +226,8 @@ OC.L10N.register(
     "[Tomorrow]" : "[Imorgon]",
     "[Yesterday]" : "[Igår]",
     "Event does not exist" : "Händelsen existerar inte",
-    "Delete this occurrence" : "Radera denna förekomst",
-    "Delete this and all future" : "Radera denna och alla kommande",
+    "Delete this occurrence" : "Ta bort denna förekomst",
+    "Delete this and all future" : "Ta bort denna och alla kommande",
     "Details" : "Detaljer",
     "Attendees" : "Deltagare",
     "Reminders" : "Påminnelser",
