@@ -10,6 +10,7 @@ OC.L10N.register(
     "Share link" : "Share link",
     "New calendar" : "يېڭى يىلنامە",
     "Cancel" : "ۋاز كەچ",
+    "Actions" : "مەشغۇلاتلار",
     "Email" : "تورخەت",
     "never" : "ھەرگىز",
     "Repeat" : "قايتىلا",
@@ -20,8 +21,9 @@ OC.L10N.register(
     "Personal" : "شەخسىي",
     "Attendees" : "قاتناشقۇچىلار",
     "Close" : "ياپ",
+    "today" : "بۈگۈن",
     "Location" : "ئورنى",
     "Description" : "چۈشەندۈرۈش",
     "Play" : "چال"
 },
-"nplurals=1; plural=0;");
+"nplurals=2; plural=(n != 1);");
