@@ -10,6 +10,7 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Chúng tôi muốn thông báo với bạn rằng %s vừa đăng tải thông tin vào lịch calendar »%s«.",
     "Open »%s«" : "Mở »%s«",
     "Cheers!" : "Xin chúc mừng!",
+    "Upcoming events" : "Các sự kiện sắp diễn ra",
     "Calendar" : "Lịch",
     "A Calendar app for Nextcloud" : "Một ứng dụng Lịch nhắc nhở cho Hệ thống",
     "Previous day" : "Ngày trước",
@@ -23,6 +24,7 @@ OC.L10N.register(
     "Day" : "Ngày",
     "Week" : "Tuần",
     "Month" : "Tháng",
+    "List" : "Danh sách",
     "Untitled calendar" : "Lịch không tiêu đề",
     "Edit name" : "Sửa đổi tên",
     "Saving name …" : "Đang lưu tên  …",
@@ -76,6 +78,7 @@ OC.L10N.register(
     "Creating subscription …" : "Đang tạo đăng kí theo dõi mới  …",
     "An error occurred, unable to create the calendar." : "Một lỗi đã xảy ra, không thẻ tạo lịch.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vui lòng nhập vào một liên kết khả dụng ( bắt đầu với http://, https://, webcal://, hoặc webcals://)",
+    "Could not update calendar order." : "Không thể cập nhật thứ tự của lịch",
     "Import calendars" : "Nhập lịch",
     "Please select a calendar to import into …" : "Vui lòng chọn một lịch để nhập vào  …",
     "Filename" : "Tên tập tin",
@@ -90,7 +93,16 @@ OC.L10N.register(
     "Automatic" : "Tự động",
     "Automatic ({detected})" : " ({detected}) tự động",
     "New setting was not saved successfully." : "Thiết lập mới không được lưu thành công",
+    "Shortcut overview" : "Bản xem trước của lối tắt",
+    "or" : "hoặc",
+    "Previous period" : "Kỳ trước",
+    "Next period" : "Kỳ tiếp theo",
+    "Day view" : "Xem theo ngày",
+    "Week view" : "Xem theo tuần",
+    "Month view" : "Xem theo tháng",
     "Actions" : "Hành động",
+    "Create event" : "Tạo sự kiện mới",
+    "Show shortcuts" : "Hiển thị các lối tắt",
     "Enable birthday calendar" : "Bật lịch sinh nhật",
     "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
     "Enable simplified editor" : "Bật chỉnh sửa đơn giản",
@@ -99,6 +111,7 @@ OC.L10N.register(
     "Show week numbers" : "Hiển thị số tuần",
     "Copy primary CalDAV address" : "Sao chép địa chỉ CalDAV chính",
     "Copy iOS/macOS CalDAV address" : "Sao chép địa chỉ CalDAV cho iOS/macOC",
+    "Show keyboard shortcuts" : "Hiển thị các phím tắt",
     "Settings & import" : "Thiết lập & Nhập vào",
     "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
     "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
@@ -148,7 +161,6 @@ OC.L10N.register(
     "No match found" : "Không có khớp lệnh nào được tìm thấy",
     "No attendees yet" : "Chưa có giờ tham gia",
     "(organizer)" : "(organizer)",
-    "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "Để gửi đi các lời mời và thu xếp các phản hồi, [linkopen] thêm email của bạn vào thiết lập cá nhân [linkclose].",
     "Remove color" : "Gỡ màu",
     "Event title" : "Tiêu đề sự kiện",
     "All day" : "Cả ngày",
@@ -205,6 +217,8 @@ OC.L10N.register(
     "Personal" : "Cá nhân",
     "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Tự động phát hiện múi giờ xác định múi giờ của bạn trên hệ thống UTC. \nĐây gần như là một trong những kết quả của các phương thức bảo mật của trình duyệt của bạn.\nVui lòng đặt múi giờ của bạn một cách thủ công trong các thiết lập của Lịch. ",
     "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Múi giờ được cấu hình của bạn ({timezoneId}) không được tìm thấy. Đang trở về lại hệ thống UTC.\nVui lòng thay đổi múi giờ của bạn trong Thiết lập và báo cáo vấn đề này. ",
+    "No more events today" : "Không có thêm sự kiện nào hôm nay",
+    "Event does not exist" : "Sự kiện không tồn tại",
     "Delete this occurrence" : "Xóa định kỳ này",
     "Delete this and all future" : "Xóa địnhy kỳ này và tất cả tương lai của nó",
     "Details" : "Chi tiết",
@@ -260,8 +274,21 @@ OC.L10N.register(
     "Untitled event" : "Sự kiện không tiêu đề",
     "Untitled task" : "Nhiệm vụ không tiêu đề",
     "Please ask your administrator to enable the Tasks App." : "Vui lòng hỏi quản trị viên của bạn để bật ứng dụng Nhiệm Vụ",
+    "prev" : "trước",
+    "next" : "tiếp theo",
+    "prev year" : "năm trước",
+    "next year" : "năm tới",
     "today" : "hôm nay",
+    "list" : "danh sách",
+    "W" : "w",
+    "all-day" : "nguyên-ngày",
+    "%n more" : "thêm %n",
+    "No events to display" : "không có sự kiện để hiển thị",
     "_+%n more_::_+%n more_" : ["+ thêm %n "],
+    "No events" : "không có sự kiện",
+    "Create a new event or change the visible time-range" : "Tạo sự kiện mới hoặc thay đổi khung thời gian hiển thị",
+    "It might have been deleted, or there was a typo in a link" : "Đường dẫn có thể đã bị xóa, hoặc đã có lỗi đánh máy trong liên kết",
+    "It might have been deleted, or there was a typo in the link" : "Đường dẫn có thể đã bị xóa, hoặc đã có lỗi đánh máy trong liên kết",
     "When shared show" : "Khi được chia sẻ thì cho thấy",
     "When shared show full event" : "Khi được chia sẻ thì cho thấy đầy đủ sự kiện",
     "When shared show only busy" : "Khi được chia sẻ thì chỉ cho thấy đang bận",
@@ -274,6 +301,7 @@ OC.L10N.register(
     "Status" : "Trạng thái",
     "Confirmed" : "Đã xác nhận",
     "Tentative" : "Chưa chắc chắn",
+    "Canceled" : "Đã bị hủy",
     "Confirmation about the overall status of the event." : "Sự xác nhận về tình trạng tổng thể của sự kiện.",
     "Show as" : "Cho thấy với",
     "Take this event into account when calculating free-busy information." : "Lưu ý sự kiện này vào tài khoản khi tính toán về thông tin bận-rãnh",
@@ -349,6 +377,11 @@ OC.L10N.register(
     "Running" : "Chạy bộ",
     "Go for a run" : "Đi chạy bộ",
     "Marathon" : "Chạy marathon",
+    "Video-conference" : "Hội nghị video",
+    "Conference-call" : "Hội nghị qua điện thoại",
+    "Video-call" : "Cuộc gọi video",
+    "Video-chat" : "Trò chuyện video",
+    "Video-meeting" : "Họp qua video",
     "Call" : "Cuộc gọi",
     "Calling" : "Đang gọi",
     "Christmas" : "Giáng sinh",
