@@ -25,11 +25,11 @@ OC.L10N.register(
     "Personal" : "個人",
     "Attendees" : "出席者",
     "Reminders" : "提示",
-    "Activity" : "動態",
     "Close" : "關閉",
     "Week {number} of {year}" : "{year} 年的第 {number} 週",
     "Daily" : "每日",
     "Weekly" : "每星期",
+    "today" : "今日",
     "Location" : "位置",
     "Description" : "描述",
     "Mail" : "郵件",
