@@ -47,6 +47,7 @@ OC.L10N.register(
     "Copy subscription link" : "複製訂閱的連結",
     "Copying link …" : "正在複製連結 ...",
     "Delete share link" : "刪除分享連結",
+    "Deleting share link …" : "正在刪除共享連結 ...",
     "Share with users or groups" : "與使用者或群組分享",
     "No users or groups" : "沒有使用者或群組",
     "can edit" : "可編輯",
@@ -125,7 +126,7 @@ OC.L10N.register(
     "Description" : "描述",
     "Status" : "狀態",
     "Confirmed" : "已確認",
-    "Tentative" : "測試的",
+    "Tentative" : "暫定的",
     "Categories" : "分類",
     "Movie" : "電影",
     "Cinema" : "電影院",
